'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var graphql = require('graphql');
var Joi$1 = require('@hapi/joi');
var Joi$1__default = _interopDefault(Joi$1);
var joiPostalCode = _interopDefault(require('joi-postalcode'));

const validate = value => {
  Joi$1__default.assert(value, Joi$1__default.date().iso(), new TypeError(`Value is not a valid Date: ${value}`));
  return value;
};

const DateTimeScalar = `scalar DateTime`;
const DateTime = new graphql.GraphQLScalarType({
  name: `DateTime`,
  description: `Use JavaScript Date object for date/time fields.`,

  serialize(value) {
    const date = typeof value === `string` ? new Date(Date.parse(value)) : value;
    validate(date);
    return date.toJSON();
  },

  parseValue(value) {
    const date = new Date(value);
    return validate(date);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only parse strings to dates but got a: ${ast.kind}`);
    }

    const date = new Date(ast.value);

    if (ast.value !== date.toJSON()) {
      throw new graphql.GraphQLError(`Value is not a valid Date format (YYYY-MM-DDTHH:MM:SS.SSSZ): ${ast.value}`);
    }

    return validate(date);
  }

});

const validate$1 = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().email(), new TypeError(`Value is not a valid email address: ${value}`));
  return value;
};

const EmailAddressScalar = `scalar EmailAddress`;
const EmailAddress = new graphql.GraphQLScalarType({
  name: `EmailAddress`,
  description: `A field whose value conforms to the standard internet email address format as specified in RFC822: https://www.w3.org/Protocols/rfc822/.`,

  serialize(value) {
    return validate$1(value);
  },

  parseValue(value) {
    return validate$1(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as email addresses but got a: ${ast.kind}`);
    }

    return validate$1(ast.value);
  }

});

const validate$2 = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().guid(), new TypeError(`Value is not a valid GUID: ${value}`));
  return value;
};

const GUIDScalar = `scalar GUID`;
const GUID = new graphql.GraphQLScalarType({
  name: `GUID`,
  description: `A field whose value is a generic Globally Unique Identifier: https://en.wikipedia.org/wiki/Universally_unique_identifier.`,

  serialize(value) {
    return validate$2(value);
  },

  parseValue(value) {
    return validate$2(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as GUIDs but got a: ${ast.kind}`);
    }

    return validate$2(ast.value);
  }

});

const validate$3 = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().hex(), new TypeError(`Value is not a valid hexadecimal value: ${value}`));
  return value;
};

const HexadecimalScalar = `scalar Hexadecimal`;
const Hexadecimal = new graphql.GraphQLScalarType({
  name: `Hexadecimal`,
  description: `A field whose value is a hexadecimal: https://en.wikipedia.org/wiki/Hexadecimal.`,

  serialize(value) {
    return validate$3(value);
  },

  parseValue(value) {
    return validate$3(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as a hexadecimal but got a: ${ast.kind}`);
    }

    return validate$3(ast.value);
  }

});

const validate$4 = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().regex(/^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3}|[A-Fa-f0-9]{8})$/), new TypeError(`Value is not a valid HexColorCode: ${value}`));
  return value;
};

const HexColorCodeScalar = `scalar HexColorCode`;
const HexColorCode = new graphql.GraphQLScalarType({
  name: `HexColorCode`,
  description: `A field whose value is a hex color code: https://en.wikipedia.org/wiki/Web_colors.`,

  serialize(value) {
    return validate$4(value);
  },

  parseValue(value) {
    return validate$4(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as hex color codes but got a: ${ast.kind}`);
    }

    return validate$4(ast.value);
  }

});

const validate$5 = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().regex(/^hsl\(\s*(-?\d+|-?\d*.\d+)\s*,\s*(-?\d+|-?\d*.\d+)%\s*,\s*(-?\d+|-?\d*.\d+)%\s*\)$/), new TypeError(`Value is not a valid HSL color: ${value}`));
  return value;
};

const HSLScalar = `scalar HSL`;
const HSL = new graphql.GraphQLScalarType({
  name: `HSL`,
  description: `A field whose value is a CSS HSL color: https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#hsl()_and_hsla().`,

  serialize(value) {
    return validate$5(value);
  },

  parseValue(value) {
    return validate$5(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as HSL colors but got a: ${ast.kind}`);
    }

    return validate$5(ast.value);
  }

});

const validate$6 = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().regex(/^hsla\(\s*(-?\d+|-?\d*.\d+)\s*,\s*(-?\d+|-?\d*.\d+)%\s*,\s*(-?\d+|-?\d*.\d+)%\s*,\s*(-?\d+|-?\d*.\d+)\s*\)$/), new TypeError(`Value is not a valid HSLA color: ${value}`));
  return value;
};

const HSLAScalar = `scalar HSLA`;
const HSLA = new graphql.GraphQLScalarType({
  name: `HSLA`,
  description: `A field whose value is a CSS HSLA color: https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#hsl()_and_hsla().`,

  serialize(value) {
    return validate$6(value);
  },

  parseValue(value) {
    return validate$6(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as HSLA colors but got a: ${ast.kind}`);
    }

    return validate$6(ast.value);
  }

});

const validate$7 = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().ip({
    version: `ipv4`
  }), new TypeError(`Value is not a valid IPv4 address: ${value}`));
  return value;
};

const IPv4Scalar = `scalar IPv4`;
const IPv4 = new graphql.GraphQLScalarType({
  name: `IPv4`,
  description: `A field whose value is a IPv4 address: https://en.wikipedia.org/wiki/IPv4.`,

  serialize(value) {
    return validate$7(value);
  },

  parseValue(value) {
    return validate$7(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as IPv4 addresses but got a: ${ast.kind}`);
    }

    return validate$7(ast.value);
  }

});

const validate$8 = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().ip({
    version: `ipv6`
  }), new TypeError(`Value is not a valid IPv6 address: ${value}`));
  return value;
};

const IPv6Scalar = `scalar IPv6`;
const IPv6 = new graphql.GraphQLScalarType({
  name: `IPv6`,
  description: `A field whose value is a IPv6 address: https://en.wikipedia.org/wiki/IPv6.`,

  serialize(value) {
    return validate$8(value);
  },

  parseValue(value) {
    return validate$8(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as IPv6 addresses but got a: ${ast.kind}`);
    }

    return validate$8(ast.value);
  }

});

const validate$9 = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, [Joi$1__default.string().regex(/^(?:ISBN(?:-10)?:? *((?=\d{1,5}([ -]?)\d{1,7}\2?\d{1,6}\2?\d)(?:\d\2*){9}[\dX]))$/i), Joi$1__default.string().regex(/^(?:ISBN(?:-13)?:? *(97(?:8|9)([ -]?)(?=\d{1,5}\2?\d{1,7}\2?\d{1,6}\2?\d)(?:\d\2*){9}\d))$/i)], new TypeError(`Value is not a valid ISBN number: ${value}`));
  return value;
};

const ISBNScalar = `scalar ISBN`;
const ISBN = new graphql.GraphQLScalarType({
  name: `ISBN`,
  description: `A field whose value is a ISBN-10 or ISBN-13 number: https://en.wikipedia.org/wiki/International_Standard_Book_Number.`,

  serialize(value) {
    return validate$9(value);
  },

  parseValue(value) {
    return validate$9(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as ISBN numbers but got a: ${ast.kind}`);
    }

    return validate$9(ast.value);
  }

});

const validate$a = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().regex(/^(?:[0-9A-Fa-f]{2}([:-]?)[0-9A-Fa-f]{2})(?:(?:\1|\.)(?:[0-9A-Fa-f]{2}([:-]?)[0-9A-Fa-f]{2})){2}$/), new TypeError(`Value is not a valid MAC address: ${value}`));
  return value;
};

const MACScalar = `scalar MAC`;
const MAC = new graphql.GraphQLScalarType({
  name: `MAC`,
  description: `A field whose value is a IEEE 802 48-bit MAC address: https://en.wikipedia.org/wiki/MAC_address.`,

  serialize(value) {
    return validate$a(value);
  },

  parseValue(value) {
    return validate$a(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as MAC addresses but got a: ${ast.kind}`);
    }

    return validate$a(ast.value);
  }

});

const validate$b = value => {
  Joi$1__default.assert(value, Joi$1__default.any().invalid(Infinity, -Infinity), new TypeError(`Value is not a finite number: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.number().required(), new TypeError(`Value is not a number: ${value}`));
  const parsed = parseFloat(value);
  Joi$1__default.assert(parsed, Joi$1__default.number().negative(), new TypeError(`Value is not a negative number: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().less(0), new TypeError(`Value is not less than 0: ${parsed}`));
  return parsed;
};

const NegativeFloatScalar = `scalar NegativeFloat`;
const NegativeFloat = new graphql.GraphQLScalarType({
  name: `NegativeFloat`,
  description: `Floats that will have a value less than 0.`,

  serialize(value) {
    return validate$b(value);
  },

  parseValue(value) {
    return validate$b(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.FLOAT) {
      throw new graphql.GraphQLError(`Can only validate floating point numbers as negative floating point numbers but got a: ${ast.kind}`);
    }

    return validate$b(ast.value);
  }

});

const validate$c = value => {
  Joi$1__default.assert(value, Joi$1__default.any().invalid(Infinity, -Infinity), new TypeError(`Value is not a finite number: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.number().required(), new TypeError(`Value is not a number: ${value}`));
  const parsed = parseInt(value, 10);
  Joi$1__default.assert(parsed, Joi$1__default.number().integer(), new TypeError(`Value is not an integer: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().negative(), new TypeError(`Value is not a negative number: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().less(0), new TypeError(`Value is not less than 0: ${parsed}`));
  return parsed;
};

const NegativeIntScalar = `scalar NegativeInt`;
const NegativeInt = new graphql.GraphQLScalarType({
  name: `NegativeInt`,
  description: `Integers that will have a value less than 0.`,

  serialize(value) {
    return validate$c(value);
  },

  parseValue(value) {
    return validate$c(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.INT) {
      throw new graphql.GraphQLError(`Can only validate integers as negative integers but got a: ${ast.kind}`);
    }

    return validate$c(ast.value);
  }

});

const validate$d = value => {
  Joi$1__default.assert(value, Joi$1__default.any().invalid(Infinity, -Infinity), new TypeError(`Value is not a finite number: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.number().required(), new TypeError(`Value is not a number: ${value}`));
  const parsed = parseFloat(value);
  Joi$1__default.assert(parsed, Joi$1__default.number().max(0), new TypeError(`Value is not a non-positive number: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().negative().allow(0), new TypeError(`Value is not a negative number: ${parsed}`));
  return parsed;
};

const NonPositiveFloatScalar = `scalar NonPositiveFloat`;
const NonPositiveFloat = new graphql.GraphQLScalarType({
  name: `NonPositiveFloat`,
  description: `Floats that will have a value of 0 or less.`,

  serialize(value) {
    return validate$d(value);
  },

  parseValue(value) {
    return validate$d(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.FLOAT) {
      throw new graphql.GraphQLError(`Can only validate floating point numbers as non-positive floating point numbers but got a: ${ast.kind}`);
    }

    return validate$d(ast.value);
  }

});

const validate$e = value => {
  Joi$1__default.assert(value, Joi$1__default.any().invalid(Infinity, -Infinity), new TypeError(`Value is not a finite number: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.number().required(), new TypeError(`Value is not a number: ${value}`));
  const parsed = parseInt(value, 10);
  Joi$1__default.assert(parsed, Joi$1__default.number().integer(), new TypeError(`Value is not an integer: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().max(0), new TypeError(`Value is not a non-positive number: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().negative().allow(0), new TypeError(`Value is not a negative number: ${parsed}`));
  return parsed;
};

const NonPositiveIntScalar = `scalar NonPositiveInt`;
const NonPositiveInt = new graphql.GraphQLScalarType({
  name: `NonPositiveInt`,
  description: `Integers that will have a value of 0 or less.`,

  serialize(value) {
    return validate$e(value);
  },

  parseValue(value) {
    return validate$e(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.INT) {
      throw new graphql.GraphQLError(`Can only validate integers as non-positive integers but got a: ${ast.kind}`);
    }

    return validate$e(ast.value);
  }

});

const validate$f = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().regex(/^\+\d{11,15}$/), new TypeError(`Value is not a valid phone number of the form +17895551234 (10-15 digits): ${value}`));
  return value;
};

const PhoneNumberScalar = `scalar PhoneNumber`;
const PhoneNumber = new graphql.GraphQLScalarType({
  name: `PhoneNumber`,
  description: `A field whose value conforms to the standard E.164 format as specified in: https://en.wikipedia.org/wiki/E.164. Basically this is +17895551234.`,

  serialize(value) {
    return validate$f(value);
  },

  parseValue(value) {
    return validate$f(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as phone numbers but got a: ${ast.kind}`);
    }

    return validate$f(ast.value);
  }

});

const validate$g = value => {
  Joi$1__default.assert(value, Joi$1__default.any().invalid(Infinity, -Infinity), new TypeError(`Value is not a finite number: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.number().required(), new TypeError(`Value is not a number: ${value}`));
  const parsed = parseInt(value, 10);
  Joi$1__default.assert(parsed, Joi$1__default.number().port(), new TypeError(`Value is not a valid TCP port: ${parsed}`));
  return parsed;
};

const PortScalar = `scalar Port`;
const Port = new graphql.GraphQLScalarType({
  name: `Port`,
  description: `A field whose value is a valid TCP port within the range of 0 to 65535: https://en.wikipedia.org/wiki/Transmission_Control_Protocol#TCP_ports`,

  serialize(value) {
    return validate$g(value);
  },

  parseValue(value) {
    return validate$g(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.INT) {
      throw new graphql.GraphQLError(`Can only validate integers as TCP ports but got a: ${ast.kind}`);
    }

    return validate$g(ast.value);
  }

});

const validate$h = value => {
  Joi$1__default.assert(value, Joi$1__default.any().invalid(Infinity, -Infinity), new TypeError(`Value is not a finite number: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.number().required(), new TypeError(`Value is not a number: ${value}`));
  const parsed = parseFloat(value);
  Joi$1__default.assert(parsed, Joi$1__default.number().positive(), new TypeError(`Value is not a positive number: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().greater(0), new TypeError(`Value is not greater than 0: ${parsed}`));
  return parsed;
};

const PositiveFloatScalar = `scalar PositiveFloat`;
const PositiveFloat = new graphql.GraphQLScalarType({
  name: `PositiveFloat`,
  description: `Floats that will have a value greater than 0.`,

  serialize(value) {
    return validate$h(value);
  },

  parseValue(value) {
    return validate$h(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.FLOAT) {
      throw new graphql.GraphQLError(`Can only validate floating point numbers as positive floating point numbers but got a: ${ast.kind}`);
    }

    return validate$h(ast.value);
  }

});

const validate$i = value => {
  Joi$1__default.assert(value, Joi$1__default.any().invalid(Infinity, -Infinity), new TypeError(`Value is not a finite number: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.number().required(), new TypeError(`Value is not a number: ${value}`));
  const parsed = parseInt(value, 10);
  Joi$1__default.assert(parsed, Joi$1__default.number().integer(), new TypeError(`Value is not an integer: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().positive(), new TypeError(`Value is not a positive number: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().greater(0), new TypeError(`Value is not greater than 0: ${parsed}`));
  return parsed;
};

const PositiveIntScalar = `scalar PositiveInt`;
const PositiveInt = new graphql.GraphQLScalarType({
  name: `PositiveInt`,
  description: `Integers that will have a value greater than 0.`,

  serialize(value) {
    return validate$i(value);
  },

  parseValue(value) {
    return validate$i(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.INT) {
      throw new graphql.GraphQLError(`Can only validate integers as positive integers but got a: ${ast.kind}`);
    }

    return validate$i(ast.value);
  }

});

const Joi = Joi$1.extend(joiPostalCode);
const countries = [`US`, `GB`, `DE`, `CA`, `FR`, `IT`, `AU`, `NL`, `ES`, `DK`, `SE`, `BE`, `IN`];

const validate$j = value => {
  Joi.assert(value, Joi.string(), new TypeError(`Value is not string: ${value}`));
  Joi.assert(value, [...countries.map(country => Joi.string().postalCode(country))], new TypeError(`Value is not a valid postal code: ${value}`));
  return value;
};

const PostalCodeScalar = `scalar PostalCode`;
const PostalCode = new graphql.GraphQLScalarType({
  name: `PostalCode`,
  description: `A field whose value conforms to the standard postal code formats for United States, United Kingdom, Germany, Canada, France, Italy, Australia, Netherlands, Spain, Denmark, Sweden, Belgium or India.`,

  serialize(value) {
    return validate$j(value);
  },

  parseValue(value) {
    return validate$j(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as phone numbers but got a: ${ast.kind}`);
    }

    return validate$j(ast.value);
  }

});

const validate$k = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().regex(/^rgb\(\s*(-?\d+|-?\d*\.\d+(?=%))(%?)\s*,\s*(-?\d+|-?\d*\.\d+(?=%))(\2)\s*,\s*(-?\d+|-?\d*\.\d+(?=%))(\2)\s*\)$/), new TypeError(`Value is not a valid RGB color: ${value}`));
  return value;
};

const RGBScalar = `scalar RGB`;
const RGB = new graphql.GraphQLScalarType({
  name: `RGB`,
  description: `A field whose value is a CSS RGB color: https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#rgb()_and_rgba().`,

  serialize(value) {
    return validate$k(value);
  },

  parseValue(value) {
    return validate$k(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as RGB colors but got a: ${ast.kind}`);
    }

    return validate$k(ast.value);
  }

});

const validate$l = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.string().regex(/^rgba\(\s*(-?\d+|-?\d*\.\d+(?=%))(%?)\s*,\s*(-?\d+|-?\d*\.\d+(?=%))(\2)\s*,\s*(-?\d+|-?\d*\.\d+(?=%))(\2)\s*,\s*(-?\d+|-?\d*.\d+)\s*\)$/), new TypeError(`Value is not a valid RGBA color: ${value}`));
  return value;
};

const RGBAScalar = `scalar RGBA`;
const RGBA = new graphql.GraphQLScalarType({
  name: `RGBA`,
  description: `A field whose value is a CSS RGBA color: https://developer.mozilla.org/en-US/docs/Web/CSS/color_value#rgb()_and_rgba().`,

  serialize(value) {
    return validate$l(value);
  },

  parseValue(value) {
    return validate$l(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as RGBA colors but got a: ${ast.kind}`);
    }

    return validate$l(ast.value);
  }

});

const validate$m = value => {
  Joi$1__default.assert(value, Joi$1__default.any().invalid(Infinity, -Infinity), new TypeError(`Value is not a finite number: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.number().required(), new TypeError(`Value is not a number: ${value}`));
  const parsed = parseFloat(value);
  Joi$1__default.assert(parsed, Joi$1__default.number().min(0), new TypeError(`Value is not a non-negative number: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().positive().allow(0), new TypeError(`Value is not a non-negative number/: ${parsed}`));
  return parsed;
};

const UnsignedFloatScalar = `scalar UnsignedFloat`;
const UnsignedFloat = new graphql.GraphQLScalarType({
  name: `UnsignedFloat`,
  description: `Floats that will have a value of 0 or more.`,

  serialize(value) {
    return validate$m(value);
  },

  parseValue(value) {
    return validate$m(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.FLOAT) {
      throw new graphql.GraphQLError(`Can only validate floating point numbers as non-negative floating point numbers but got a: ${ast.kind}`);
    }

    return validate$m(ast.value);
  }

});

const validate$n = value => {
  Joi$1__default.assert(value, Joi$1__default.any().invalid(Infinity, -Infinity), new TypeError(`Value is not a finite number: ${value}`));
  Joi$1__default.assert(value, Joi$1__default.number().required(), new TypeError(`Value is not a number: ${value}`));
  const parsed = parseInt(value, 10);
  Joi$1__default.assert(parsed, Joi$1__default.number().integer(), new TypeError(`Value is not an integer: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().min(0), new TypeError(`Value is not a non-negative number: ${parsed}`));
  Joi$1__default.assert(parsed, Joi$1__default.number().positive().allow(0), new TypeError(`Value is not a positive number: ${parsed}`));
  return parsed;
};

const UnsignedIntScalar = `scalar UnsignedInt`;
const UnsignedInt = new graphql.GraphQLScalarType({
  name: `UnsignedInt`,
  description: `Integers that will have a value of 0 or more.`,

  serialize(value) {
    return validate$n(value);
  },

  parseValue(value) {
    return validate$n(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.INT) {
      throw new graphql.GraphQLError(`Can only validate integers as non-negative integers but got a: ${ast.kind}`);
    }

    return validate$n(ast.value);
  }

});

const validate$o = value => {
  Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
  Joi$1__default.assert(value, [Joi$1__default.string().uri(), Joi$1__default.string().dataUri()], new TypeError(`Value is not a valid URL: ${value}`));
  return value;
};

const URLScalar = `scalar URL`;
const URL = new graphql.GraphQLScalarType({
  name: `URL`,
  description: `A field whose value conforms to the standard URL format as specified in RFC3986: https://www.ietf.org/rfc/rfc3986.txt.`,

  serialize(value) {
    return validate$o(value);
  },

  parseValue(value) {
    return validate$o(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== graphql.Kind.STRING) {
      throw new graphql.GraphQLError(`Can only validate strings as URLs but got a: ${ast.kind}`);
    }

    return validate$o(ast.value);
  }

});

const RegularExpressionFactory = (name, regex) => {
  const validate = value => {
    Joi$1__default.assert(value, Joi$1__default.string(), new TypeError(`Value is not string: ${value}`));
    Joi$1__default.assert(value, Joi$1__default.string().regex(new RegExp(regex), {
      name
    }), new TypeError(`Value does not match the regular expression ${regex}: ${value}`));
    return value;
  };

  return {
    scalar: `scalar ${name}`,
    resolver: new graphql.GraphQLScalarType({
      name,
      description: `A field whose value matches the provided regular expression ${regex}.`,

      serialize(value) {
        return validate(value);
      },

      parseValue(value) {
        return validate(value);
      },

      parseLiteral(ast) {
        if (ast.kind !== graphql.Kind.STRING) {
          throw new graphql.GraphQLError(`Can only validate strings as regular expressions but got a: ${ast.kind}`);
        }

        return validate(ast.value);
      }

    })
  };
};

var index = new Map([[DateTimeScalar, DateTime], [EmailAddressScalar, EmailAddress], [GUIDScalar, GUID], [HexadecimalScalar, Hexadecimal], [HexColorCodeScalar, HexColorCode], [HSLScalar, HSL], [HSLAScalar, HSLA], [IPv4Scalar, IPv4], [IPv6Scalar, IPv6], [ISBNScalar, ISBN], [MACScalar, MAC], [NegativeFloatScalar, NegativeFloat], [NegativeIntScalar, NegativeInt], [NonPositiveFloatScalar, NonPositiveFloat], [NonPositiveIntScalar, NonPositiveInt], [PhoneNumberScalar, PhoneNumber], [PortScalar, Port], [PositiveFloatScalar, PositiveFloat], [PositiveIntScalar, PositiveInt], [PostalCodeScalar, PostalCode], [RGBScalar, RGB], [RGBAScalar, RGBA], [UnsignedFloatScalar, UnsignedFloat], [UnsignedIntScalar, UnsignedInt], [URLScalar, URL]]);

exports.DateTime = DateTime;
exports.DateTimeScalar = DateTimeScalar;
exports.EmailAddress = EmailAddress;
exports.EmailAddressScalar = EmailAddressScalar;
exports.GUID = GUID;
exports.GUIDScalar = GUIDScalar;
exports.HSL = HSL;
exports.HSLA = HSLA;
exports.HSLAScalar = HSLAScalar;
exports.HSLScalar = HSLScalar;
exports.HexColorCode = HexColorCode;
exports.HexColorCodeScalar = HexColorCodeScalar;
exports.Hexadecimal = Hexadecimal;
exports.HexadecimalScalar = HexadecimalScalar;
exports.IPv4 = IPv4;
exports.IPv4Scalar = IPv4Scalar;
exports.IPv6 = IPv6;
exports.IPv6Scalar = IPv6Scalar;
exports.ISBN = ISBN;
exports.ISBNScalar = ISBNScalar;
exports.MAC = MAC;
exports.MACScalar = MACScalar;
exports.NegativeFloat = NegativeFloat;
exports.NegativeFloatScalar = NegativeFloatScalar;
exports.NegativeInt = NegativeInt;
exports.NegativeIntScalar = NegativeIntScalar;
exports.NonPositiveFloat = NonPositiveFloat;
exports.NonPositiveFloatScalar = NonPositiveFloatScalar;
exports.NonPositiveInt = NonPositiveInt;
exports.NonPositiveIntScalar = NonPositiveIntScalar;
exports.PhoneNumber = PhoneNumber;
exports.PhoneNumberScalar = PhoneNumberScalar;
exports.Port = Port;
exports.PortScalar = PortScalar;
exports.PositiveFloat = PositiveFloat;
exports.PositiveFloatScalar = PositiveFloatScalar;
exports.PositiveInt = PositiveInt;
exports.PositiveIntScalar = PositiveIntScalar;
exports.PostalCode = PostalCode;
exports.PostalCodeScalar = PostalCodeScalar;
exports.RGB = RGB;
exports.RGBA = RGBA;
exports.RGBAScalar = RGBAScalar;
exports.RGBScalar = RGBScalar;
exports.RegularExpressionFactory = RegularExpressionFactory;
exports.URL = URL;
exports.URLScalar = URLScalar;
exports.UnsignedFloat = UnsignedFloat;
exports.UnsignedFloatScalar = UnsignedFloatScalar;
exports.UnsignedInt = UnsignedInt;
exports.UnsignedIntScalar = UnsignedIntScalar;
exports.default = index;
//# sourceMappingURL=index.js.map
