import { GraphQLScalarType, GraphQLError, Kind } from "graphql";
import Joi from "@hapi/joi";

const validate = value => {
  Joi.assert(value, Joi.string(), new TypeError(`Value is not string: ${value}`));
  Joi.assert(value, Joi.string().regex(/^(?:[0-9A-Fa-f]{2}([:-]?)[0-9A-Fa-f]{2})(?:(?:\1|\.)(?:[0-9A-Fa-f]{2}([:-]?)[0-9A-Fa-f]{2})){2}$/), new TypeError(`Value is not a valid MAC address: ${value}`));
  return value;
};

export const MACScalar = `scalar MAC`;
export const MAC = new GraphQLScalarType({
  name: `MAC`,
  description: `A field whose value is a IEEE 802 48-bit MAC address: https://en.wikipedia.org/wiki/MAC_address.`,

  serialize(value) {
    return validate(value);
  },

  parseValue(value) {
    return validate(value);
  },

  parseLiteral(ast) {
    if (ast.kind !== Kind.STRING) {
      throw new GraphQLError(`Can only validate strings as MAC addresses but got a: ${ast.kind}`);
    }

    return validate(ast.value);
  }

});